import unittest
import sys
sys.path.append("../MqttImageUploader")
import json

import MqttImageUploader as miu

url = "127.0.0.1"

def publish_callback(client, userdata, result):
    print("published data motherfuckers")
    print(result)

class MqttImageUploaderTest(unittest.TestCase):

    def testPublish(self):

        uploader = miu.MqttImageUploader(
            url, 1883, "test/test")
        uploader.UploadData(
            "./image.jpg", '{"timestamp":123123123}', publish_callback)



    def testWithDictionryJson(self):
        uploader = miu.MqttImageUploader(url, 1883, "test/test")
        j = dict()
        j['timestamp'] = 123123123
        uploader.UploadData('./image.jpg', json.dumps(j), publish_callback)

 

if __name__ == '__main__':
    unittest.main()



import io
import time
import paho.mqtt.client as mqtt
import base64
import json
from io import BytesIO

from PIL import Image, ImageColor


def on_connect(client, userdata, flags, rc):
    print("Connected with result code " + str(rc))

# def on_message(client, userdata, msg):
# 	print(msg.topic+" "+str(msg.payload))


def on_publish(client, userdata, result):
    print("data published \n")
    print(result)


class MqttImageUploader:
    def __init__(self, host, port, topic):
        self.host = host
        self.port = port
        self.topic = topic

    def UploadData(self, image_name, json_string, callback):
        client = mqtt.Client()
        client.on_connect = on_connect
        client.on_publish = callback
        print "connecting to %s on port %s\npublishing on topic %s" % (
            self.host, self.port, self.topic)
        client.connect(self.host, self.port, 60)
        img = Image.open(image_name)

        asString = base64.b64encode(img.tobytes())
        j = json.loads(json_string)
        j['image'] = asString
        j['timestamp'] = time.time()
        client.publish(self.topic, json.dumps(j), qos=0)
